@@ -18,18 +18,30 @@ sub new {
 
 sub function_with_col {
     my ( $sf, $func, $col ) = @_;
+    my $driver = $sf->{i}{driver};
     $func = uc( $func );
     if ( $func eq 'LTRIM' ) {
-        return "TRIM(LEADING FROM $col)"  if $sf->{i}{driver} =~ /^(?:Pg|Firebird|Informix)\z/;
+        return "TRIM(LEADING FROM $col)"  if $driver =~ /^(?:Pg|Firebird|Informix)\z/;
         return "LTRIM($col)";
     }
     elsif ( $func eq 'RTRIM' ) {
-        return "TRIM(TRAILING FROM $col)" if $sf->{i}{driver} =~ /^(?:Pg|Firebird|Informix)\z/;
+        return "TRIM(TRAILING FROM $col)" if $driver =~ /^(?:Pg|Firebird|Informix)\z/;
         return "RTRIM($col)";
     }
-    elsif ( $func eq 'BIT_LENGTH' ) {
-        return "OCTET_LENGTH($col)" if $sf->{i}{driver} eq 'Informix';
-        return "BIT_LENGTH($col)";
+    elsif ( $func eq 'OCTET_LENGTH' ) {
+        return "OCTET_LENGTH($col)";
+    }
+    elsif ( $func =~ /^CHAR_LENGTH/ ) {
+        if ( $driver eq 'SQLite' ) {
+            return "LENGTH($col)";
+        }
+        elsif ( $driver eq 'DB2' ) {
+            return "CHARACTER_LENGTH($col,CODEUNITS16)" if $func eq 'CHAR_LENGTH_16';
+            return "CHARACTER_LENGTH($col,CODEUNITS32)" if $func eq 'CHAR_LENGTH_32';
+        }
+        else {
+            return "CHAR_LENGTH($col)";
+        }
     }
     else {
         return "$func($col)";
@@ -54,6 +66,35 @@ sub function_with_col_and_arg {
         return "TRUNC($col,$arg)"     if $sf->{i}{driver} =~ /^(?:Pg|Firebird|Informix|Oracle)\z/;
         return "TRUNCATE($col,$arg)";
     }
+    else {
+        return "$func($col,$arg)"; # none
+    }
+}
+
+
+sub function_with_col_and_2args {
+    my ( $sf, $func, $col, $arg1, $arg2 ) = @_;
+    my $driver = $sf->{i}{driver};
+    if ( $func eq 'REPLACE' ) {
+        my $string_to_replace =  $sf->{d}{dbh}->quote( $arg1 );
+        my $replacement_string = $sf->{d}{dbh}->quote( $arg2 );
+        return "REPLACE($col,$string_to_replace,$replacement_string)";
+    }
+    elsif ( $func eq 'SUBSTR' ) {
+        my $startpos = $arg1;
+        my $length = $arg2;
+        if ( $driver =~ /^(?:SQLite|mysql|MariaDB)\z/ ) {
+            return "SUBSTR($col,$startpos,$length)" if length $length;
+            return "SUBSTR($col,$startpos)";
+        }
+        else {
+            return "SUBSTRING($col FROM $startpos FOR $length)" if length $length;
+            return "SUBSTRING($col FROM $startpos)";
+        }
+    }
+    else {
+        return "$func($col,$arg1,$arg2)"; # none
+    }
 }
 
 
@@ -77,28 +118,29 @@ sub concatenate {
 
 sub epoch_to_date {
     my ( $sf, $col, $interval ) = @_;
-    return "DATE($col/$interval,'unixepoch','localtime')"                                  if $sf->{i}{driver} eq 'SQLite';
-    return "FROM_UNIXTIME($col/$interval,'%Y-%m-%d')"                                      if $sf->{i}{driver} =~ /^(?:mysql|MariaDB)\z/;
-    return "TO_TIMESTAMP(${col}::bigint/$interval)::date"                                  if $sf->{i}{driver} eq 'Pg';
-    return "DATEADD(CAST($col AS BIGINT)/$interval SECOND TO DATE '1970-01-01')"           if $sf->{i}{driver} eq 'Firebird';
-    return "TIMESTAMP('1970-01-01') + ($col/$interval) SECONDS"                            if $sf->{i}{driver} eq 'DB2';
-    return "TO_DATE('1970-01-01','YYYY-MM-DD') + NUMTODSINTERVAL($col/$interval,'SECOND')" if $sf->{i}{driver} eq 'Oracle';
+    my $driver = $sf->{i}{driver};
+    return "DATE($col/$interval,'unixepoch','localtime')"                                  if $driver eq 'SQLite';
+    return "FROM_UNIXTIME($col/$interval,'%Y-%m-%d')"                                      if $driver =~ /^(?:mysql|MariaDB)\z/;
+    return "TO_TIMESTAMP(${col}::bigint/$interval)::date"                                  if $driver eq 'Pg';
+    return "DATEADD(CAST($col AS BIGINT)/$interval SECOND TO DATE '1970-01-01')"           if $driver eq 'Firebird';
+    return "TIMESTAMP('1970-01-01') + ($col/$interval) SECONDS"                            if $driver eq 'DB2';
+    return "TO_DATE('1970-01-01','YYYY-MM-DD') + NUMTODSINTERVAL($col/$interval,'SECOND')" if $driver eq 'Oracle';
 }
 
 
 sub epoch_to_datetime {
     my ( $sf, $col, $interval ) = @_;
-    if ( $sf->{i}{driver} eq 'SQLite' ) {
+    my $driver = $sf->{i}{driver};
+    if ( $driver eq 'SQLite' ) {
         if ( $interval == 1 ) {
             return "DATETIME($col,'unixepoch','localtime')";
         }
         else {
-            return "STRFTIME( '%Y-%m-%d %H:%M:%f', $col/$interval.0, 'unixepoch', 'localtime' )";
+            return "STRFTIME('%Y-%m-%d %H:%M:%f',$col/$interval.0, 'unixepoch','localtime')";
         }
     }
-    elsif ( $sf->{i}{driver} =~ /^(?:mysql|MariaDB)\z/ ) {
+    elsif ( $driver =~ /^(?:mysql|MariaDB)\z/ ) {
         # mysql: FROM_UNIXTIME doesn't work with negative timestamps
-        # https://stackoverflow.com/questions/26299149/timestamp-with-a-millisecond-precision-how-to-save-them-in-mysql
         if ( $interval == 1 ) {
             return "FROM_UNIXTIME($col)";
         }
@@ -107,21 +149,20 @@ sub epoch_to_datetime {
         }
         else {
             return "FROM_UNIXTIME($col * 0.000001)";
-            #return "FROM_UNIXTIME($col/$interval,'%Y-%m-%d %H:%i:%s.%f')";
         }
     }
-    elsif ( $sf->{i}{driver} eq 'Pg' ) {
+    elsif ( $driver eq 'Pg' ) {
         if ( $interval == 1 ) {
             return "TO_TIMESTAMP(${col}::bigint)::timestamp"
         }
         elsif ( $interval == 1_000 ) {
-            return "TO_CHAR(TO_TIMESTAMP(${col}::bigint/$interval.0) at time zone 'UTC', 'yyyy-mm-dd hh24:mi:ss.ff3')";
+            return "TO_CHAR(TO_TIMESTAMP(${col}::bigint/$interval.0) at time zone 'UTC','yyyy-mm-dd hh24:mi:ss.ff3')";
         }
         else {
-            return "TO_CHAR(TO_TIMESTAMP(${col}::bigint/$interval.0) at time zone 'UTC', 'yyyy-mm-dd hh24:mi:ss.ff6')";
+            return "TO_CHAR(TO_TIMESTAMP(${col}::bigint/$interval.0) at time zone 'UTC','yyyy-mm-dd hh24:mi:ss.ff6')";
         }
     }
-    elsif ( $sf->{i}{driver} eq 'Firebird' ) {
+    elsif ( $driver eq 'Firebird' ) {
         if ( $interval == 1 ) {
             return "SUBSTRING(CAST(DATEADD(SECOND,CAST($col AS BIGINT),TIMESTAMP '1970-01-01 00:00:00') AS VARCHAR(24)) FROM 1 FOR 19)";
         }
@@ -130,22 +171,25 @@ sub epoch_to_datetime {
             return "SUBSTRING(CAST(DATEADD(MILLISECOND,CAST($col AS BIGINT)/$interval,TIMESTAMP '1970-01-01 00:00:00') AS VARCHAR(24)) FROM 1 FOR 23)";
         }
         else {
-            $interval /= 1_000;                     # works with: $interval.0
+            $interval /= 1_000;                        # don't remove the ".0"
             return "CAST(DATEADD(MILLISECOND,CAST($col AS BIGINT)/$interval.0,TIMESTAMP '1970-01-01 00:00:00') AS VARCHAR(24))";
         }
     }
-    elsif ( $sf->{i}{driver} eq 'DB2' ) {
+    elsif ( $driver eq 'DB2' ) {
         if ( $interval == 1 ) {
-            return "TIMESTAMP('1970-01-01 00:00:00', 0) + $col SECONDS";
+            return "TIMESTAMP('1970-01-01 00:00:00',0) + $col SECONDS";
         }
         elsif ( $interval == 1_000 ) {
-            return "TIMESTAMP('1970-01-01 00:00:00', 3) + ($col/$interval) SECONDS";
+            return "TIMESTAMP('1970-01-01 00:00:00',3) + ($col/$interval) SECONDS";
         }
         else {
-            return "TIMESTAMP('1970-01-01 00:00:00', 6) + ($col/$interval) SECONDS";
+            return "TIMESTAMP('1970-01-01 00:00:00',6) + ($col/$interval) SECONDS";
         }
     }
-    elsif ( $sf->{i}{driver} eq 'Oracle' ) {
+    elsif ( $driver eq 'Informix' ) {
+        return "DBINFO('utc_to_datetime',$col/$interval)";
+    }
+    elsif ( $driver eq 'Oracle' ) {
         if ( $interval == 1 ) {
             return "TO_TIMESTAMP('1970-01-01 00:00:00','YYYY-MM-DD HH24:MI:SS') + NUMTODSINTERVAL($col,'SECOND')"
         }
@@ -156,11 +200,6 @@ sub epoch_to_datetime {
 }
 
 
-sub replace {
-    my ( $sf, $col, $string_to_replace, $replacement_string ) = @_;
-    return "REPLACE($col,$string_to_replace,$replacement_string)";
-}
-
 
 
 
